---
name: Arbor Enhancement Proposal
about: An outline and rationale for a new feature or major change to Arbor. Use this label ONLY if you have formulated this and have some or a few ideas for its implementation.
title: ''
labels:
- 'AEP'
- 'enhancement'
assignees: ''

---
<!-- Please add relevant labels to categorize your AEP. -->

## Goal


## Rationale


## Scope


## Implementation
